# Using HappyFeat

After starting or loading a workspace, *HappyFeat*'s main GUI is launched. It is made up of three parts, spread out in three panels: [**Feature Extraction**](extract.md), [**Feature Visualization**](visualize.md) and [**Classifier Training**](train.md).
